========
PrettyQt
========


.. image:: https://img.shields.io/pypi/v/prettyqt.svg
        :target: https://pypi.python.org/pypi/prettyqt
        :alt: PyPi

.. image:: https://img.shields.io/travis/phil65/PrettyQt.svg
        :target: https://travis-ci.org/phil65/PrettyQt
        :alt: Travis CI

.. image:: https://readthedocs.org/projects/prettyqt/badge/?version=latest
        :target: https://prettyqt.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/phil65/PrettyQt/shield.svg
        :target: https://pyup.io/repos/github/phil65/PrettyQt/
        :alt: Updates

.. image:: https://codecov.io/gh/phil65/PrettyQt/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/phil65/PrettyQt

Pythonic layer on top of PyQt5 / PySide2


* Free software: MIT license
* Documentation: https://prettyqt.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
